@@ -2,6 +2,8 @@
 Run all examples and then compare to gallery versions, if available.
 """
 
+from __future__ import absolute_import
+from __future__ import print_function
 from clawpack.clawutil import regression_tests, make_all
 import os
 
@@ -12,10 +14,10 @@ env['OMP_NUM_THREADS'] = '3'
 
 make_all.make_all(make_clean_first=True, env=env)
 
-print "\n-----------------------------------------------------------\n"
+print("\n-----------------------------------------------------------\n")
 
 all_ok = regression_tests.test_subdirs()
 if all_ok:
-    print "===> All tests pass"
+    print("===> All tests pass")
 else:
-    print "===> Some test(s) failed"
+    print("===> Some test(s) failed")
