@@ -88,7 +88,7 @@ program amr1
     use amr_module, only: timeBound,timeStepgrid, timeFlagger,timeBufnst,timeFilvalTot
     use amr_module, only: timeBoundCPU,timeStepGridCPU,timeSetauxCPU,timeRegriddingCPU
     use amr_module, only: timeSetaux, timeSetauxCPU, timeValoutCPU
-    use amr_module, only: kcheck, iorder, lendim, lenmax
+    use amr_module, only: kcheck, iorder, lendim, lenmax, memsize
 
     use amr_module, only: dprint, eprint, edebug, gprint, nprint, pprint
     use amr_module, only: rprint, sprint, tprint, uprint
@@ -298,6 +298,7 @@ program amr1
     !  Refinement Control
     call opendatafile(inunit, amrfile)
 
+    read(inunit,*) memsize  ! initial size of alloc array
     read(inunit,*) max1d  ! max size of each grid patch
 
     read(inunit,*) mxnest
@@ -579,6 +580,8 @@ program amr1
     call tick(nvar,cut,nstart,vtime,time,naux,t0,rest,dt_max)
     ! --------------------------------------------------------
 
+    write(*,"('See fort.amr for more info on this run and memory usage')")
+
     call system_clock(clock_finish,clock_rate)
     call cpu_time(cpu_finish)
     
@@ -762,9 +765,10 @@ program amr1
 
     write(outunit,*)
     write(outunit,*)
-    write(outunit,"('current  space usage = ',i12)") lentotsave
-    write(outunit,"('maximum  space usage = ',i12)") lenmax
-    write(outunit,"('need space dimension = ',i12,/)") lendim
+    write(outunit,"('alloc array statistics:')")
+    write(outunit,"('    current alloc usage = ',i12)") lentotsave
+    write(outunit,"('    maximum alloc usage = ',i12)") lenmax
+    write(outunit,"('required alloc memsize >= ',i12,/)") lendim
 
     write(outunit,"('number of cells advanced for time integration = ',f20.6)")&
                     rvol
