@@ -9,16 +9,15 @@
 
 
 subroutine init_alloc()
+
+    ! new way, use allocatable arrays, not pointers
     
     use amr_module
     implicit none
     
-!    if (.not.allocated(storage)) then   ! old way, changed mjb sept. 2014
-    if (.not.allocated(alloc)) then      ! new way, use allocatable arrays, not pointers
-        memsize = 1000000
-!        allocate(storage(memsize)) 
+    if (.not.allocated(alloc)) then
+        !memsize = 1000000  # Now read in from amr.data by amr1.f90
         allocate(alloc(memsize))
-!        alloc => storage
         print *, "Storage allocated..."
     else
         print *, "Storage already allocated!"
