@@ -1,4 +1,10 @@
 c
+!> Integrate all grids at the input **level** by one step of its delta(t)
+!!
+!! this includes:  
+!! - setting the ghost cells 
+!! - advancing the solution on the grid
+!! - adjusting fluxes for flux conservation step later
 c --------------------------------------------------------------
 c
       subroutine advanc (level,nvar,dtlevnew,vtime,naux)
@@ -7,11 +13,16 @@ c
       implicit double precision (a-h,o-z)
 
 
-      logical vtime
+      logical    vtime
       integer omp_get_thread_num, omp_get_max_threads
       integer mythread/0/, maxthreads/1/
       integer listgrids(numgrids(level))
-      integer clock_start, clock_finish, clock_rate
+      integer(kind=8) :: clock_start, clock_finish, clock_rate
+      integer(kind=8) :: clock_startStepgrid,clock_startBound,
+     &                   clock_finishBound
+      real(kind=8) cpu_start, cpu_finish
+      real(kind=8) cpu_startBound, cpu_finishBound
+      real(kind=8) cpu_startStepgrid, cpu_finishStepgrid
 
 c     maxgr is maximum number of grids  many things are
 c     dimensioned at, so this is overall. only 1d array
@@ -27,41 +38,56 @@ c                  advancing the solution on the grid
 c                  adjusting fluxes for flux conservation step later
 c :::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 c
+c get start time for more detailed timing by level
+      call system_clock(clock_start,clock_rate)
+      call cpu_time(cpu_start)
+
+
       hx   = hxposs(level)
       hy   = hyposs(level)
       delt = possk(level)
 c     this is linear alg.
-      call prepgrids(listgrids,numgrids(level),level)
+c     call prepgrids(listgrids,numgrids(level),level)
 c
-c get start time for more detailed timing by level
-       call system_clock(clock_start,clock_rate)
+
+      call system_clock(clock_startBound,clock_rate)
+      call cpu_time(cpu_startBound)
+
 
 c     maxthreads initialized to 1 above in case no openmp
 !$    maxthreads = omp_get_max_threads()
 
 c We want to do this regardless of the threading type
-!$OMP PARALLEL DO PRIVATE(j,locnew, locaux, mptr,nx,ny,mitot
-!$OMP&                    ,mjtot,time),
-!$OMP&            SHARED(level,nvar,naux,alloc,intrat,delt,
-!$OMP&                   nghost,node,rnode,numgrids,listgrids),
+!$OMP PARALLEL DO PRIVATE(j,locnew, locaux, mptr,nx,ny,mitot,
+!$OMP&                    mjtot,time,levSt),
+!$OMP&            SHARED(level, nvar, naux, alloc, intrat, delt,
+!$OMP&                   listOfGrids,listStart,nghost,
+!$OMP&                   node,rnode,numgrids,listgrids),
 !$OMP&            SCHEDULE (dynamic,1)
 !$OMP&            DEFAULT(none)
-      do  j = 1, numgrids(level)
-          mptr = listgrids(j)
-          nx     = node(ndihi,mptr) - node(ndilo,mptr) + 1
-          ny     = node(ndjhi,mptr) - node(ndjlo,mptr) + 1
-          mitot  = nx + 2*nghost
-          mjtot  = ny + 2*nghost
-          locnew = node(store1,mptr)
-          locaux = node(storeaux,mptr)
-          time   = rnode(timemult,mptr)
-c
+      do j = 1, numgrids(level)
+         !mptr   = listgrids(j)
+         levSt = listStart(level)
+         mptr   = listOfGrids(levSt+j-1)
+         !write(*,*)"old ",listgrids(j)," new",mptr
+         nx     = node(ndihi,mptr) - node(ndilo,mptr) + 1
+         ny     = node(ndjhi,mptr) - node(ndjlo,mptr) + 1
+         mitot  = nx + 2*nghost
+         mjtot  = ny + 2*nghost
+         locnew = node(store1,mptr)
+         locaux = node(storeaux,mptr)
+         time   = rnode(timemult,mptr)
+c     
           call bound(time,nvar,nghost,alloc(locnew),mitot,mjtot,mptr,
      1               alloc(locaux),naux)
 
-        end do
+       end do
 !$OMP END PARALLEL DO
-
+      call system_clock(clock_finishBound,clock_rate)
+      call cpu_time(cpu_finishBound)
+      timeBound = timeBound + clock_finishBound - clock_startBound
+      timeBoundCPU=timeBoundCPU+cpu_finishBound-cpu_startBound
+      
 c
 c save coarse level values if there is a finer level for wave fixup
       if (level+1 .le. mxnest) then
@@ -72,7 +98,10 @@ c save coarse level values if there is a finer level for wave fixup
 c
       dtlevnew = rinfinity
       cfl_level = 0.d0    !# to keep track of max cfl seen on each level
+
 c 
+      call system_clock(clock_startStepgrid,clock_rate)
+      call cpu_time(cpu_startStepgrid)
 
 
 !$OMP PARALLEL DO PRIVATE(j,mptr,nx,ny,mitot,mjtot)  
@@ -80,14 +109,17 @@ c
 !$OMP&            SHARED(rvol,rvoll,level,nvar,mxnest,alloc,intrat)
 !$OMP&            SHARED(nghost,intratx,intraty,hx,hy,naux,listsp)
 !$OMP&            SHARED(node,rnode,dtlevnew,numgrids,listgrids)
+!$OMP&            SHARED(listOfGrids,listStart,levSt)
 !$OMP&            SCHEDULE (DYNAMIC,1)
 !$OMP&            DEFAULT(none)
-      do  j = 1, numgrids(level)
-          mptr = listgrids(j)
-          nx     = node(ndihi,mptr) - node(ndilo,mptr) + 1
-          ny     = node(ndjhi,mptr) - node(ndjlo,mptr) + 1
-          mitot  = nx + 2*nghost
-          mjtot  = ny + 2*nghost
+      do j = 1, numgrids(level)
+         !mptr   = listgrids(j)
+         levSt = listStart(level)
+         mptr = listOfGrids(levSt+j-1)
+         nx     = node(ndihi,mptr) - node(ndilo,mptr) + 1
+         ny     = node(ndjhi,mptr) - node(ndjlo,mptr) + 1
+         mitot  = nx + 2*nghost
+         mjtot  = ny + 2*nghost
 c
           call par_advanc(mptr,mitot,mjtot,nvar,naux,dtnew)
 !$OMP CRITICAL (newdt)
@@ -98,7 +130,12 @@ c
 !$OMP END PARALLEL DO
 c
       call system_clock(clock_finish,clock_rate)
+      call cpu_time(cpu_finish)
       tvoll(level) = tvoll(level) + clock_finish - clock_start
+      tvollCPU(level) = tvollCPU(level) + cpu_finish - cpu_start
+      timeStepgrid = timeStepgrid +clock_finish-clock_startStepgrid
+      timeStepgridCPU=timeStepgridCPU+cpu_finish-cpu_startStepgrid      
+      
       cflmax = dmax1(cflmax, cfl_level)
 
 c
@@ -107,7 +144,7 @@ c
 c
 c -------------------------------------------------------------
 c
-       subroutine prepgrids(listgrids,num, level)
+       subroutine prepgrids(listgrids, num, level)
 
        use amr_module
        implicit double precision (a-h,o-z)
@@ -130,9 +167,11 @@ c
 c
 c --------------------------------------------------------------
 c
+!> Integrate grid **mptr**. grids are done in parallel.
       subroutine par_advanc (mptr,mitot,mjtot,nvar,naux,dtnew)
 c
       use amr_module
+      use gauges_module, only: update_gauges, num_gauges
       implicit double precision (a-h,o-z)
 
 
@@ -155,7 +194,7 @@ c
       level = node(nestlevel,mptr)
       hx    = hxposs(level)
       hy    = hyposs(level)
-      delt  =  possk(level)
+      delt  = possk(level)
       nx    = node(ndihi,mptr) - node(ndilo,mptr) + 1
       ny    = node(ndjhi,mptr) - node(ndjlo,mptr) + 1
       time  = rnode(timemult,mptr)
@@ -171,15 +210,15 @@ c  since integrator will overwrite it. only for grids not at
 c  the finest level. finest level grids do not maintain copies
 c  of old and new time solution values.
 c
-          if (level .lt. mxnest) then
+         if (level .lt. mxnest) then
              ntot   = mitot * mjtot * nvar
 cdir$ ivdep
              do 10 i = 1, ntot
  10            alloc(locold + i - 1) = alloc(locnew + i - 1)
-          endif
+         endif
 c
-      xlow = rnode(cornxlo,mptr) - nghost*hx
-      ylow = rnode(cornylo,mptr) - nghost*hy
+         xlow = rnode(cornxlo,mptr) - nghost*hx
+         ylow = rnode(cornylo,mptr) - nghost*hy
 
 !$OMP CRITICAL(rv)
       rvol = rvol + nx * ny
@@ -187,51 +226,64 @@ c
 !$OMP END CRITICAL(rv)
 
 
-      locaux = node(storeaux,mptr)
+         locaux = node(storeaux,mptr)
 c
-      if (node(ffluxptr,mptr) .ne. 0) then
-         lenbc  = 2*(nx/intratx(level-1)+ny/intraty(level-1))
-         locsvf = node(ffluxptr,mptr)
-         locsvq = locsvf + nvar*lenbc
-         locx1d = locsvq + nvar*lenbc
-         call qad(alloc(locnew),mitot,mjtot,nvar,
-     1            alloc(locsvf),alloc(locsvq),lenbc,
-     2            intratx(level-1),intraty(level-1),hx,hy,
-     3            naux,alloc(locaux),alloc(locx1d),delt,mptr)
-      endif
+         if (node(ffluxptr,mptr) .ne. 0) then
+            lenbc  = 2*(nx/intratx(level-1)+ny/intraty(level-1))
+            locsvf = node(ffluxptr,mptr)
+            locsvq = locsvf + nvar*lenbc
+            locx1d = locsvq + nvar*lenbc
+            call qad(alloc(locnew),mitot,mjtot,nvar,
+     1               alloc(locsvf),alloc(locsvq),lenbc,
+     2               intratx(level-1),intraty(level-1),hx,hy,
+     3               naux,alloc(locaux),alloc(locx1d),delt,mptr)
+         endif
 
-c        # see if the grid about to advanced has gauge data to output
-c        # this corresponds to previous time step, but output done
+c        # See if the grid about to be advanced has gauge data to output.
+c        # This corresponds to previous time step, but output done
 c        # now to make linear interpolation easier, since grid
 c        # now has boundary conditions filled in.
-c        # no testing here for mgauges>0 so that do not
-c        # need to use gauges.i. the only time advanc is
-c        # called that isn't "real" is in the initial setting
-c        # up of grids (setgrd), but source grids are 0 there so
-c        # nothing will be output.
 
-c    should change the way  dumpguage does io - right now is critical section
-           call dumpgauge(alloc(locnew),alloc(locaux),xlow,ylow,
-     .                    nvar,mitot,mjtot,naux,mptr)
+c     should change the way print_gauges does io - right now is critical section
+c     no more,  each gauge has own array.
+
+      if (num_gauges > 0) then
+           call update_gauges(alloc(locnew:locnew+nvar*mitot*mjtot),
+     .                       alloc(locaux:locaux+naux*mitot*mjtot),
+     .                       xlow,ylow,nvar,mitot,mjtot,naux,mptr)
+         endif
 
 c
-      call stepgrid(alloc(locnew),fm,fp,gm,gp,
-     2            mitot,mjtot,nghost,
-     3            delt,dtnew,hx,hy,nvar,
-     4            xlow,ylow,time,mptr,naux,alloc(locaux))
+         if (dimensional_split .eq. 0) then
+c           # Unsplit method
+         call stepgrid(alloc(locnew),fm,fp,gm,gp,
+     2                  mitot,mjtot,nghost,
+     3                  delt,dtnew,hx,hy,nvar,
+     4                  xlow,ylow,time,mptr,naux,alloc(locaux))
+         else if (dimensional_split .eq. 1) then
+c           # Godunov splitting
+         call stepgrid_dimSplit(alloc(locnew),fm,fp,gm,gp,
+     2               mitot,mjtot,nghost,
+     3               delt,dtnew,hx,hy,nvar,
+     4               xlow,ylow,time,mptr,naux,alloc(locaux))
+         else 
+c           # should never get here due to check in amr2
+            write(6,*) '*** Strang splitting not supported'
+            stop
+         endif
 
       if (node(cfluxptr,mptr) .ne. 0)
      2   call fluxsv(mptr,fm,fp,gm,gp,
      3               alloc(node(cfluxptr,mptr)),mitot,mjtot,
      4               nvar,listsp(level),delt,hx,hy)
-      if (node(ffluxptr,mptr) .ne. 0) then
+         if (node(ffluxptr,mptr) .ne. 0) then
          lenbc = 2*(nx/intratx(level-1)+ny/intraty(level-1))
-         locsvf = node(ffluxptr,mptr)
+            locsvf = node(ffluxptr,mptr)
          call fluxad(fm,fp,gm,gp,
      2               alloc(locsvf),mptr,mitot,mjtot,nvar,
-     4               lenbc,intratx(level-1),intraty(level-1),
+     4                  lenbc,intratx(level-1),intraty(level-1),
      5               nghost,delt,hx,hy)
-      endif
+         endif
 c
 c        write(outunit,969) mythread,delt, dtnew
 c969     format(" thread ",i4," updated by ",e15.7, " new dt ",e15.7)
