@@ -25,24 +25,16 @@ subroutine resize_storage(new_size,status)
     real(kind=8), allocatable, target, dimension(:) :: new_storage
     
 
-    if (memsize < new_size) then
-        print *, "Expanding storage from ", memsize," to ", new_size
-        allocate(new_storage(new_size),STAT=status)
-        if (status > 0) then
-            return
-        endif
-        new_storage(1:memsize) = storage
-
-        call move_alloc(new_storage,storage)
-
-        alloc => storage
-        memsize = new_size
-    else
-        print *,'new_size < memsize,'
-        print *,'new_size = ',new_size
-        print *,'memsize = ',memsize
-        stop
+    print *, "Expanding storage from ", memsize," to ", new_size
+    allocate(new_storage(new_size),STAT=status)
+    if (status > 0) then
+        return
     endif
+    new_storage(1:memsize) = alloc     ! new way, use allocatable, not pointer       
+
+    call move_alloc(new_storage,alloc)
+
+    memsize = new_size
     
     return
     
