@@ -1,5 +1,8 @@
 
+from __future__ import absolute_import
+from __future__ import print_function
 import os,sys,glob,re,shutil
+from six.moves import range
 
 #=================================================================
 def convert():
@@ -16,17 +19,17 @@ def convert():
     elif os.path.isfile('amr2ez.data'):
         ndim = 2
         #rundata = make_rundata(2, amr=True)
-        print "2d amr not yet implemented"
+        print("2d amr not yet implemented")
     elif os.path.isfile('claw3ez.data'):
         ndim = 3
         #rundata = make_rundata(3)
-        print "3d not yet implemented"
+        print("3d not yet implemented")
     elif os.path.isfile('amr3ez.data'):
         ndim = 3
         #rundata = make_rundata(2, amr=True)
-        print "3d amr not yet implemented"
+        print("3d amr not yet implemented")
     else:
-        print "Could not find a clawpack data file"
+        print("Could not find a clawpack data file")
 
     make_README(ndim)
     fix_setprob(ndim)
@@ -38,12 +41,12 @@ def make_rundata(ndim):
     fname43 = 'claw%sez.data.claw43' % ndim
     if not os.path.isfile(fname43):
         try:
-	    shutil.move(fname, fname43)
-	    print "=== Moved %s to %s"  % (fname, fname43)
-	except:
-	    print "*** Could not find ", fname
+            shutil.move(fname, fname43)
+            print("=== Moved %s to %s"  % (fname, fname43))
+        except:
+            print("*** Could not find ", fname)
             raise
-	    return
+            return
     clawdata_file = open(fname43,'r')
     lines = clawdata_file.readlines()
     class rundata(object):
@@ -58,7 +61,7 @@ def make_rundata(ndim):
         if outstyle!=1:
             outstyle = 1
             tfinal = 1.0
-            print "*** Warning: need to check outstyle in setrun.py"
+            print("*** Warning: need to check outstyle in setrun.py")
         dt_initial  = float(next(lines))
         dt_max      = float(next(lines))
         cfl_max     = float(next(lines))
@@ -115,8 +118,8 @@ def next(lines):
         numstring = result.group('string')
         numstring = numstring.replace('d','e')  # for floating notation
     except:
-        print '*** Failed on line: ',line
-	numstring = '0'
+        print('*** Failed on line: ',line)
+        numstring = '0'
     return numstring
 
 
@@ -377,16 +380,16 @@ if __name__ == '__main__':
     # Set up run-time parameters and write all data files.
     import sys
     if len(sys.argv) == 2:
-	rundata = setrun(sys.argv[1])
+        rundata = setrun(sys.argv[1])
     else:
-	rundata = setrun()
+        rundata = setrun()
 
     rundata.write()
     """)
 
 
     setrun.close()
-    print "=== Created setrun.py"
+    print("=== Created setrun.py")
     # end of make_setrun
 
 #========================================================================
@@ -466,7 +469,7 @@ def setplot(plotdata):
 
     """)
     setplot.close()
-    print "=== Created setplot.py"
+    print("=== Created setplot.py")
     # end of make_setplot1
 
 #========================================================================
@@ -549,7 +552,7 @@ def setplot(plotdata):
 
     """)
     setplot.close()
-    print "=== Created setplot.py"
+    print("=== Created setplot.py")
 
     # end of make_setplot2
 
@@ -557,12 +560,12 @@ def setplot(plotdata):
 def make_Makefile1():
     if not os.path.isfile('Makefile.claw43'):
         try:
-	    shutil.move('Makefile','Makefile.claw43')
-	    print "=== Moved Makefile to Makefile.claw43"
-	except:
-	    print "*** Could not find Makefile"
+            shutil.move('Makefile','Makefile.claw43')
+            print("=== Moved Makefile to Makefile.claw43")
+        except:
+            print("*** Could not find Makefile")
             raise
-	    return
+            return
     oldmake = open('Makefile.claw43','r')
     mkfile = oldmake.read()
 
@@ -605,7 +608,7 @@ FFLAGS =
     if result:
         objs = result.group('objs')  # local object files
     else:
-        print "*** No local files?"
+        print("*** No local files?")
 
     newmake.write("\nCLAW_SOURCES =")
     objs = objs.replace('.o','.f',100)
@@ -621,7 +624,7 @@ CLAW_LIB = $(CLAW)/clawpack/1d/lib
     if result:
         libobjs = result.group('libobjs')  # library object files
     else:
-        print "*** No library files?"
+        print("*** No library files?")
 
     libobjs = libobjs.replace('.o','.f',100)
     libobjs = libobjs.replace(r'$(CLAW)/clawpack/1d/lib','$(CLAW_LIB)',100)
@@ -644,7 +647,7 @@ include $(CLAWMAKE)
     """)
 
     newmake.close()
-    print "=== Created Makefile"
+    print("=== Created Makefile")
 
     ## end of make_Makefile1
 
@@ -654,12 +657,12 @@ include $(CLAWMAKE)
 def make_Makefile2():
     if not os.path.isfile('Makefile.claw43'):
         try:
-	    shutil.move('Makefile','Makefile.claw43')
-	    print "=== Moved Makefile to Makefile.claw43"
-	except:
-	    print "*** Could not find Makefile"
+            shutil.move('Makefile','Makefile.claw43')
+            print("=== Moved Makefile to Makefile.claw43")
+        except:
+            print("*** Could not find Makefile")
             raise
-	    return
+            return
     oldmake = open('Makefile.claw43','r')
     mkfile = oldmake.read()
 
@@ -702,7 +705,7 @@ FFLAGS =
     if result:
         objs = result.group('objs')  # local object files
     else:
-        print "*** No local files?"
+        print("*** No local files?")
 
     newmake.write("\nCLAW_SOURCES =")
     objs = objs.replace('.o','.f',100)
@@ -718,7 +721,7 @@ CLAW_LIB = $(CLAW)/clawpack/2d/lib
     if result:
         libobjs = result.group('libobjs')  # library object files
     else:
-        print "*** No library files?"
+        print("*** No library files?")
 
     libobjs = libobjs.replace('.o','.f',100)
     libobjs = libobjs.replace(r'$(CLAW)/clawpack/2d/lib','$(CLAW_LIB)',100)
@@ -745,7 +748,7 @@ include $(CLAWMAKE)
     """)
 
     newmake.close()
-    print "=== Created Makefile"
+    print("=== Created Makefile")
 
     ## end of make_Makefile1
 
@@ -900,7 +903,7 @@ end_html
 
     """ % (ndim,ndim,ndim))
     readme.close()
-    print "=== Created README.txt"
+    print("=== Created README.txt")
 
     ## end of make_README
 
@@ -914,27 +917,27 @@ def fix_setprob(ndim):
 
     if (os.path.isfile('setprob.f') and \
           (not os.path.isfile('setprob.f.claw43'))):
-	shutil.move('setprob.f','setprob.f.claw43')
-	print "=== Moved setprob.f to setprob.f.claw43"
+        shutil.move('setprob.f','setprob.f.claw43')
+        print("=== Moved setprob.f to setprob.f.claw43")
         lines = open('setprob.f.claw43','r').readlines()
         setprob = open('setprob.f','w')
-	for line in lines:
-	    if line.find('implicit') > -1:
-	        setprob.write(line)
-		setprob.write("      character*12 fname\n")
-	    elif line.find('open(') > -1:
-	        regexp = re.compile(r"open.*unit\s*?=\s*?(?P<iunit>[0-9]+)\s*,")
-		result = regexp.search(line)
-		if result:
-		    iunit = result.group('iunit')
-		else:
-		    print '*** Oops, expected to find unit number in setprob.f'
-		    print '*** setprob.f is corrupted, revert from setprob.f.claw43'
-		    setprob.close()
+        for line in lines:
+            if line.find('implicit') > -1:
+                setprob.write(line)
+                setprob.write("      character*12 fname\n")
+            elif line.find('open(') > -1:
+                regexp = re.compile(r"open.*unit\s*?=\s*?(?P<iunit>[0-9]+)\s*,")
+                result = regexp.search(line)
+                if result:
+                    iunit = result.group('iunit')
+                else:
+                    print('*** Oops, expected to find unit number in setprob.f')
+                    print('*** setprob.f is corrupted, revert from setprob.f.claw43')
+                    setprob.close()
                     raise
-		    return
-		setprob.write("c\n      iunit = %s" % iunit)
-		setprob.write("""
+                    return
+                setprob.write("c\n      iunit = %s" % iunit)
+                setprob.write("""
       fname = 'setprob.data'
 c     # open the unit with new routine from Clawpack 4.4 to skip over
 c     # comment lines starting with #:
@@ -942,10 +945,10 @@ c     # comment lines starting with #:
                 \n""")
 
             else:
-	        setprob.write(line)
-	setprob.close()
+                setprob.write(line)
+        setprob.close()
   
-	print "=== Modified setprob.f"
+        print("=== Modified setprob.f")
 
     ## end of fix_setprob
    
@@ -956,6 +959,6 @@ c     # comment lines starting with #:
 if __name__ == "__main__":
     try:
         convert()
-        print "Done converting."
+        print("Done converting.")
     except:
-        print "Problem converting"
+        print("Problem converting")
