@@ -25,11 +25,15 @@ objects.
 #                     http://www.opensource.org/licenses/
 # ============================================================================
 
+from __future__ import absolute_import
+from __future__ import print_function
 import shutil
 import os
 import copy
 import re
 import logging
+import six
+from six.moves import range
 
 # ========== Parse Value Utility Function ====================================
 def _parse_value(value):
@@ -111,7 +115,7 @@ class Data(object):
                 self.add_attribute(attr,None,None)
 
         # Read data files from data_files list
-        if isinstance(data_files, basestring):
+        if isinstance(data_files, six.string_types):
             data_files = [data_files]
         elif not isinstance(data_files, list):
             raise Exception("data_files must be a list of strings")
@@ -123,7 +127,7 @@ class Data(object):
     def __str__(self):
         output = "%s%s%s\n" % ("Name".ljust(25),"Value".ljust(12),
                                     "Owner".ljust(12))
-        for (k,v) in self.iteritems():
+        for (k,v) in six.iteritems(self):
             output += "%s%s%s\n" % (str(k).ljust(25),
                                     str(v).ljust(12),
                                     str(self.__owners[k]).ljust(12))
@@ -216,7 +220,7 @@ class Data(object):
          - (list) - Returns a list of owners
         """
         owners = []
-        for (key,owner) in self.__owners.iteritems():
+        for (key,owner) in six.iteritems(self.__owners):
             if owner is None:
                 self.__owners[key] = supplementary_file
             # This simultaneously finds one instance of an owner and tests
@@ -251,7 +255,7 @@ class Data(object):
         data_paths : Path to a data file to be read in, can also be a list
                     of files to be read in.
         """
-        if isinstance(data_paths, basestring):
+        if isinstance(data_paths, six.string_types):
             data_paths = [data_paths]
 
         for filename in data_paths:
@@ -261,7 +265,7 @@ class Data(object):
 
             # self.logger.info("Reading from %s" % filename)
 
-            for lineno, line in enumerate(file(filename)):
+            for lineno, line in enumerate(open(filename)):
                 if '=:' not in line:
                     continue
 
@@ -337,8 +341,9 @@ class Data(object):
                     for key in self.__attributes:
                         temp_file.write("1 =: %s\n" % key)
                     temp_file.close()
-                except IOError, (errno, strerror):
-                    print "I/O error(%s): %s" % (errno, strerror)
+                except IOError as xxx_todo_changeme:
+                    (errno, strerror) = xxx_todo_changeme.args
+                    print("I/O error(%s): %s" % (errno, strerror))
                     raise
                 except:
                     raise
@@ -349,7 +354,7 @@ class Data(object):
             for path in data_files:
                 path = os.path.abspath(path)
                 if not(path in owners):
-                    print "%s is not a registered owner!"
+                    print("%s is not a registered owner!")
                     return
             file_list = data_files
         else:
@@ -382,7 +387,7 @@ class Data(object):
                     'temp.' + os.path.basename(data_path))
                 temp_file = open(temp_path,'w')
             except(IOError):
-                print "IOERROR"
+                print("IOERROR")
                 raise
 
             try:
@@ -412,12 +417,12 @@ class Data(object):
                             else:
                                 newstring = repr(newvalues)
 
-                            newstart = str.ljust(newstring,25)
+                            newstart = newstring.ljust(25)
                             line = line.replace(result.group('values') + "=:", \
                                 newstart + " =:")
                         else:
-                            print "Error writing out %s" % name
-                            raise AttributeError, name
+                            print("Error writing out %s" % name)
+                            raise AttributeError(name)
 
                     # Write the new line
                     temp_file.write(line)
@@ -516,7 +521,7 @@ class ClawInputData(Data):
             raise AttributeError("Only ndim=1 or 2 supported so far")
 
     def write(self):
-        print 'Creating data file claw.data for use with xclaw'
+        print('Creating data file claw.data for use with xclaw')
         make_clawdatafile(self)
 
 
@@ -630,11 +635,11 @@ class AmrclawInputData(Data):
             self.add_attribute('tprint',False)
             self.add_attribute('uprint',False)
         else:
-            print '*** Error: only ndim=1 or 2 supported so far ***'
+            print('*** Error: only ndim=1 or 2 supported so far ***')
             raise AttributeError("Only ndim=1 or 2 supported so far")
 
     def write(self):
-        print 'Creating data file amr2ez.data for use with xamr'
+        print('Creating data file amr2ez.data for use with xamr')
         make_amrclawdatafile(self)
         make_setgauges_datafile(self)
 
@@ -720,7 +725,7 @@ class SharpclawInputData(Data):
             raise AttributeError("Only ndim=1 or 2 supported so far")
 
     def write(self):
-        print 'Creating data file sharpclaw.data for use with xsclaw'
+        print('Creating data file sharpclaw.data for use with xsclaw')
         make_sharpclawdatafile(self)
 
 
@@ -742,7 +747,7 @@ def open_datafile(name, datasource='setrun.py'):
 
     import string
 
-    source = string.ljust(datasource,25)
+    source = datasource.ljust(25)
     file = open(name, 'w')
     file.write('########################################################\n')
     file.write('### DO NOT EDIT THIS FILE:  GENERATED AUTOMATICALLY ####\n')
@@ -775,8 +780,8 @@ def data_write(file, dataobj, name=None, descr=''):
         try:
             value = getattr(dataobj, name)
         except:
-            print "Variable missing: ",name
-            print "  from dataobj = ", dataobj
+            print("Variable missing: ",name)
+            print("  from dataobj = ", dataobj)
             raise
         # Convert value to an appropriate string repr
         import numpy 
@@ -793,8 +798,8 @@ def data_write(file, dataobj, name=None, descr=''):
                 string_value = 'F'
         else:
             string_value = repr(value)
-        padded_value = string.ljust(string_value, 25)
-        padded_name = string.ljust(name, 12)
+        padded_value = string_value.ljust(25)
+        padded_name = name.ljust(12)
         file.write('%s =: %s %s\n' % (padded_value, padded_name, descr))
 
 
@@ -830,7 +835,7 @@ def make_clawdatafile(clawdata):
         data_write(file, clawdata, 'tfinal', '(final time)')
 
     else:
-        print '*** Error: unrecognized outstyle'
+        print('*** Error: unrecognized outstyle')
         raise
         return
 
@@ -904,24 +909,24 @@ def make_amrclawdatafile(clawdata):
 
     data_write(file, clawdata, 'mxnest', '(max number of grid levels)')
     if len(clawdata.inratx) < max(abs(clawdata.mxnest)-1, 1):
-	raise ValueError("*** Error in data parameter: " + \
+        raise ValueError("*** Error in data parameter: " + \
               "require len(inratx) >= %s " % max(abs(clawdata.mxnest) - 1, 1))
     data_write(file, clawdata, 'inratx', '(refinement ratios)')
     if clawdata.mxnest < 0:
-	# negative mxnest indicates anisotropic refinement
-	if len(clawdata.inraty) < max(abs(clawdata.mxnest)-1, 1):
-	    raise ValueError("*** Error in data parameter: " + \
+        # negative mxnest indicates anisotropic refinement
+        if len(clawdata.inraty) < max(abs(clawdata.mxnest)-1, 1):
+            raise ValueError("*** Error in data parameter: " + \
               "require len(inraty) >= %s " % max(abs(clawdata.mxnest) - 1, 1))
         data_write(file, clawdata, 'inraty', '(refinement ratios)')
-	if ndim == 3:
-	    if len(clawdata.inratz) < max(abs(clawdata.mxnest)-1, 1):
-	        raise ValueError("*** Error in data parameter: " + \
-		  "require len(inratz) >= %s " % max(abs(clawdata.mxnest) - 1, 1))
-	    data_write(file, clawdata, 'inratz', '(refinement ratios)')
-	if len(clawdata.inratt) < max(abs(clawdata.mxnest)-1, 1):
-	    raise ValueError("*** Error in data parameter: " + \
-		  "require len(inratt) >= %s " % max(abs(clawdata.mxnest) - 1, 1))
-	data_write(file, clawdata, 'inratt', '(refinement ratios)')
+        if ndim == 3:
+            if len(clawdata.inratz) < max(abs(clawdata.mxnest)-1, 1):
+                raise ValueError("*** Error in data parameter: " + \
+                  "require len(inratz) >= %s " % max(abs(clawdata.mxnest) - 1, 1))
+            data_write(file, clawdata, 'inratz', '(refinement ratios)')
+        if len(clawdata.inratt) < max(abs(clawdata.mxnest)-1, 1):
+            raise ValueError("*** Error in data parameter: " + \
+                  "require len(inratt) >= %s " % max(abs(clawdata.mxnest) - 1, 1))
+        data_write(file, clawdata, 'inratt', '(refinement ratios)')
 
     data_write(file, clawdata, None)  # writes blank line
 
@@ -937,7 +942,7 @@ def make_amrclawdatafile(clawdata):
         data_write(file, clawdata, 'output_time_interval', '(between outputs)')
         data_write(file, clawdata, 'tfinal', '(final time)')
     else:
-        print '*** Error: unrecognized outstyle'
+        print('*** Error: unrecognized outstyle')
         raise
         return
 
@@ -960,8 +965,8 @@ def make_amrclawdatafile(clawdata):
     data_write(file, clawdata, 'maux', '(number of aux variables)')
     if len(clawdata.auxtype) != clawdata.maux:
         file.close()
-        print "*** Error: An auxtype array must be specified of length maux"
-        raise AttributeError, "require len(clawdata.auxtype) == clawdata.maux"
+        print("*** Error: An auxtype array must be specified of length maux")
+        raise AttributeError("require len(clawdata.auxtype) == clawdata.maux")
     for i in range(clawdata.maux):
         file.write("'%s'\n" % clawdata.auxtype[i])
     data_write(file, clawdata, None)
@@ -1051,7 +1056,7 @@ def make_sharpclawdatafile(clawdata):
     elif clawdata.outstyle == 3:
         data_write(file, clawdata, 'iout', '(output every iout steps)')
     else:
-        print '*** Error: unrecognized outstyle'
+        print('*** Error: unrecognized outstyle')
         raise
         return
 
@@ -1132,7 +1137,7 @@ def make_setgauges_datafile(clawdata):
     gauges = getattr(clawdata,'gauges',[])
     ngauges = len(gauges)
 
-    print 'Creating data file setgauges.data'
+    print('Creating data file setgauges.data')
     # open file and write a warning header:
     file = open_datafile('setgauges.data')
     file.write("%4i   =: ngauges\n" % ngauges)
@@ -1140,7 +1145,7 @@ def make_setgauges_datafile(clawdata):
     for gauge in gauges:
         gaugeno = gauge[0]
         if gaugeno in gaugeno_used:
-            print "*** Gauge number %s used more than once! " % gaugeno
+            print("*** Gauge number %s used more than once! " % gaugeno)
             raise Exception("Repeated gauge number")
         else:
             gaugeno_used.append(gauge[0])
@@ -1242,7 +1247,7 @@ class UserData(Data):
          self.__descr[name] = descr
 
     def write(self):
-         print 'Creating data file %s' % self.__fname
+         print('Creating data file %s' % self.__fname)
          make_userdatafile(self)
 
 class GaugeData(Data):
@@ -1261,7 +1266,7 @@ class GaugeData(Data):
         self.ngauges = len(self.__gauge_dict)
 
     def write(self):
-        print 'Creating data file gauges.data'
+        print('Creating data file gauges.data')
 
         # open file and write a warning header:
         file = open_datafile('gauges.data')
@@ -1272,7 +1277,7 @@ class GaugeData(Data):
         ndim = self.ndim
 
         # write a line for each gauge:
-        for (gaugeno, gdata) in self.__gauge_dict.iteritems():
+        for (gaugeno, gdata) in six.iteritems(self.__gauge_dict):
             tmin = gdata[2][0]
             tmax = gdata[2][1]
             if isinstance(gdata[1],(list,tuple)):
@@ -1314,7 +1319,7 @@ class GeoclawInputData(Data):
 
     def write(self):
 
-        print 'Creating data file setgeo.data'
+        print('Creating data file setgeo.data')
         # open file and write a warning header:
         file = open_datafile('setgeo.data')
         data_write(file, self, 'igravity')
@@ -1325,7 +1330,7 @@ class GeoclawInputData(Data):
         data_write(file, self, 'variable_dt_refinement_ratios')
         file.close()
 
-        print 'Creating data file settsunami.data'
+        print('Creating data file settsunami.data')
         # open file and write a warning header:
         file = open_datafile('settsunami.data')
         data_write(file, self, 'sealevel')
@@ -1338,7 +1343,7 @@ class GeoclawInputData(Data):
         data_write(file, self, 'frictiondepth')
         file.close()
 
-        print 'Creating data file settopo.data'
+        print('Creating data file settopo.data')
         # open file and write a warning header:
         file = open_datafile('settopo.data')
         self.ntopofiles = len(self.topofiles)
@@ -1347,13 +1352,13 @@ class GeoclawInputData(Data):
             try:
                 fname = os.path.abspath(tfile[-1])
             except:
-                print "*** Error: file not found: ",tfile[-1]
+                print("*** Error: file not found: ",tfile[-1])
                 raise MissingFile("file not found")
             file.write("\n'%s' \n " % fname)
             file.write("%3i %3i %3i %20.10e %20.10e \n" % tuple(tfile[:-1]))
         file.close()
 
-        print 'Creating data file setdtopo.data'
+        print('Creating data file setdtopo.data')
         # open file and write a warning header:
         file = open_datafile('setdtopo.data')
         self.mdtopofiles = len(self.dtopofiles)
@@ -1363,13 +1368,13 @@ class GeoclawInputData(Data):
             try:
                 fname = "'%s'" % os.path.abspath(tfile[-1])
             except:
-                print "*** Error: file not found: ",tfile[-1]
+                print("*** Error: file not found: ",tfile[-1])
                 raise MissingFile("file not found")
             file.write("\n%s \n" % fname)
             file.write("%3i %3i %3i\n" % tuple(tfile[:-1]))
         file.close()
 
-        print 'Creating data file setqinit.data'
+        print('Creating data file setqinit.data')
         # open file and write a warning header:
         file = open_datafile('setqinit.data')
         # self.iqinit tells which component of q is perturbed!
@@ -1379,7 +1384,7 @@ class GeoclawInputData(Data):
             try:
                 fname = "'%s'" % os.path.abspath(tfile[-1])
             except:
-                print "*** Error: file not found: ",tfile[-1]
+                print("*** Error: file not found: ",tfile[-1])
                 raise MissingFile("file not found")
             file.write("\n%s  \n" % fname)
             file.write("%3i %3i \n" % tuple(tfile[:-1]))
@@ -1406,7 +1411,7 @@ class GeoclawInputData(Data):
 #        file.close()
 
 
-        print 'Creating data file setfixedgrids.data'
+        print('Creating data file setfixedgrids.data')
         # open file and write a warning header:
         file = open_datafile('setfixedgrids.data')
         self.nfixedgrids = len(self.fixedgrids)
@@ -1417,7 +1422,7 @@ class GeoclawInputData(Data):
         file.close()
 
 
-        print 'Creating data file setregions.data'
+        print('Creating data file setregions.data')
         # open file and write a warning header:
         file = open_datafile('setregions.data')
         self.nregions = len(self.regions)
