@@ -20,7 +20,7 @@ subroutine fgmax_frompatch(mx,my,meqn,mbc,maux,q,aux,dx,dy, &
     type(fgrid), pointer :: fg
     integer :: ifg,k,mv, fg_klist_length, indexk
     real(kind=8) :: h,B,eta
-    real(kind=8) :: x1,x2,y1,y2,x,y,xupper,yupper
+    real(kind=8) :: x1,x2,y1,y2,x,y,xupper,yupper,eps
     integer :: i1,i2,j1,j2
     integer :: clock_start, clock_finish, clock_rate
     integer :: mythread, omp_get_thread_num
@@ -37,6 +37,8 @@ subroutine fgmax_frompatch(mx,my,meqn,mbc,maux,q,aux,dx,dy, &
         return
         endif 
 
+    eps = min(dx,dy)*0.01d0  ! buffer width to avoid rounding error issues
+    
     !write(61,*) '++++ In frompatch, level,mx,my,xlower,ylower'
     !write(61,*) level,mx,my,xlower,ylower
     
@@ -99,10 +101,10 @@ subroutine fgmax_frompatch(mx,my,meqn,mbc,maux,q,aux,dx,dy, &
 
         xupper = xlower+mx*dx
         yupper = ylower+my*dy
-        x1 = max(xlower, fg%x1bb) !- dx
-        x2 = min(xupper, fg%x2bb) !+ dx
-        y1 = max(ylower, fg%y1bb) !- dy
-        y2 = min(yupper, fg%y2bb) !+ dy
+        x1 = max(xlower, fg%x1bb) - eps
+        x2 = min(xupper, fg%x2bb) + eps
+        y1 = max(ylower, fg%y1bb) - eps
+        y2 = min(yupper, fg%y2bb) + eps
         if (FG_DEBUG) then
             write(61,*) 'xlower,xupper: ',xlower,xupper
             write(61,*) 'ylower,yupper: ',ylower,yupper
@@ -124,6 +126,8 @@ subroutine fgmax_frompatch(mx,my,meqn,mbc,maux,q,aux,dx,dy, &
                     
         
         ! No longer create mask, just use i1,i2, j1,j2 directly
+        ! only values(:,i1:i2,j1:j2) on this patch are needed for fgmax
+        ! adding 0.5d0 cellwidth necessary for bilinear interp option
         i1 = max(int((x1 - xlower + 0.5d0*dx) / dx), 0)
         i2 = min(int((x2 - xlower + 0.5d0*dx) / dx) + 1, mx+1)
         j1 = max(int((y1 - ylower + 0.5d0*dy) / dy), 0)
@@ -142,10 +146,29 @@ subroutine fgmax_frompatch(mx,my,meqn,mbc,maux,q,aux,dx,dy, &
             ! fgmax points are on masked grid giving index of each point,
             ! so we don't need to search through all fg%npts points.
             ! instead just loop over part of masked grid intersecting patch:
+
+            ! June 2020: RJL Fixed index error arising when x1 close to fg%xll
+            !    due to fact that int(A) = sgn(A)*floor(abs(A)) returns 0
+            !    when A is between -1 and +1 regardless of sign.
+            !    Hence i1_fg might have been 2 when it should have been 1.
+            !    And similarly in y direction.
             
-            i1_fg = max(int((x1 - fg%xll) / fg%dx + 2), 1)
+            ! reset eps since now we are computing ranges of indices 
+            ! on the fgmax grid that lie within this patch:
+            eps = min(fg%dx, fg%dy) * 0.01d0
+            
+            if (x1 <= fg%xll) then
+                i1_fg = 1
+            else
+                i1_fg = max(int((x1 - fg%xll) / fg%dx + 2), 1)
+            endif
             i2_fg = min(int((x2 - fg%xll) / fg%dx + 1), fg%nx)
-            j1_fg = max(int((y1 - fg%yll) / fg%dy + 2), 1)
+
+            if (y1 <= fg%yll) then
+                j1_fg = 1
+            else
+                j1_fg = max(int((y1 - fg%yll) / fg%dy + 2), 1)
+            endif
             j2_fg = min(int((y2 - fg%yll) / fg%dy + 1), fg%ny)
             
             
@@ -155,7 +178,7 @@ subroutine fgmax_frompatch(mx,my,meqn,mbc,maux,q,aux,dx,dy, &
             !write(6,602) fg%xll, fg%xll+(fg%nx-1)*fg%dx, &
             !             fg%yll, fg%yll+(fg%ny-1)*fg%dy
             !write(6,603) i1,i2,j1,j2, i1_fg, i2_fg, j1_fg, j2_fg
- 602        format('+++ xy: ',4f10.3)
+ 602        format('+++ xy: ',4f13.6)
  603        format('+++ ij: ',8i7)
 
  
