@@ -59,7 +59,6 @@ recursive subroutine filrecur(level,nvar,valbig,aux,naux,t,mx,my, &
 
     real(kind=8) :: eta1old, eta2old
     real(kind=8) :: veta_init_c
-    real(kind=8) :: x,y
     integer :: ii,jj
 
     ! Scratch arrays for interpolation
@@ -291,7 +290,7 @@ recursive subroutine filrecur(level,nvar,valbig,aux,naux,t,mx,my, &
                 up_slope = eta_coarse(i_coarse,j_coarse+1) - eta_coarse(i_coarse,j_coarse)
                 if (up_slope * down_slope > 0.d0) then
                     slope(2,i_coarse,j_coarse) = min(abs(up_slope), abs(down_slope)) &
-                        * sign(1.d0,eta_coarse(i_coarse+1,j_coarse) - eta_coarse(i_coarse-1,j_coarse))
+                        * sign(1.d0,eta_coarse(i_coarse,j_coarse+1) - eta_coarse(i_coarse,j_coarse-1))
                 endif
             enddo
         enddo
@@ -299,7 +298,7 @@ recursive subroutine filrecur(level,nvar,valbig,aux,naux,t,mx,my, &
         ratio_y = real(refinement_ratio_y,kind=8)  ! needs to be real for "floor" call below
         ratio_x = real(refinement_ratio_x,kind=8)
         ! Loop through patch to be filled, includes multiple coarse cells
-         do j_fine = 1, my_patch
+        do j_fine = 1, my_patch
             j_coarse     = floor((j_fine + jlo - 1) / ratio_y) - jplo + 1
             ycent_coarse = ylow_coarse + (j_coarse-.5d0)*dy_coarse
             ycent_fine   = ylower + (j_fine-1+jlo + .5d0)*dy_fine
@@ -327,20 +326,17 @@ recursive subroutine filrecur(level,nvar,valbig,aux,naux,t,mx,my, &
                                                              + eta2 * slope(2,i_coarse,j_coarse)
                     h_fine = max(eta_fine - aux(1,i_fine + nrowst - 1, j_fine + ncolst - 1), 0.d0)
 
-                    if (variable_eta_init) &
+                    if (variable_eta_init) then
                         veta_init_c = vetac(ivetac(i_coarse,j_coarse))
                         ! else it has been set to the constant sea_level
+                    endif
 
-                    x = xlow_fine + (i_fine-0.5d0)*dx_fine
-                    y = ylow_fine + (j_fine-0.5d0)*dy_fine
-
-                    if (use_force_dry_this_level .and. &
-                            (((eta_coarse(i_coarse,j_coarse) == veta_init_c) &
-                            .and. (h_fine > 0)) &
-                            .or. (t <= tend_force_dry))) then
+                    if (use_force_dry_this_level &
+                            .and. (h_fine > 0) &
+                            .and. (t <= tend_force_dry)) then
                         ! check if in force_dry region
-                        ii = int((x - xlow_fdry + 1d-7) / dx_fdry) + 1
-                        jj = int((y - ylow_fdry + 1d-7) / dy_fdry) + 1
+                        ii = int((xcent_fine - xlow_fdry + 1d-7) / dx_fdry) + 1
+                        jj = int((ycent_fine - ylow_fdry + 1d-7) / dy_fdry) + 1
                         jj = my_fdry - jj  ! since index 1 corresponds to north edge
                         if ((ii>=1) .and. (ii<=mx_fdry) .and. &
                             (jj>=1) .and. (jj<=my_fdry)) then
@@ -370,8 +366,9 @@ recursive subroutine filrecur(level,nvar,valbig,aux,naux,t,mx,my, &
 
         ! Momentum Interpolation
         do n = 2, nvar
-          do j_coarse = 2, my_coarse - 1
-            do i_coarse = 2, mx_coarse - 1
+            slope = 0.d0  ! reinitialize for each var
+            do j_coarse = 2, my_coarse - 1
+                do i_coarse = 2, mx_coarse - 1
 
                     ! Determine slopes for interpolation
                     down_slope = (valcrse(ivalc(n,i_coarse,j_coarse)) - valcrse(ivalc(n,i_coarse-1,j_coarse)))
