@@ -25,8 +25,6 @@ module qinit_module
     
     integer, private :: mx_qinit
     integer, private :: my_qinit
-    integer :: min_level_qinit
-    integer :: max_level_qinit
 
 contains
 
@@ -65,10 +63,8 @@ contains
                 return
             endif
             read(unit,*) qinit_fname
-            read(unit,"(2i2)") min_level_qinit, max_level_qinit
 
-            write(GEO_PARM_UNIT,*) '   min_level, max_level, qinit_fname:'
-            write(GEO_PARM_UNIT,*)  min_level_qinit, max_level_qinit, qinit_fname
+            write(GEO_PARM_UNIT,*)  qinit_fname
             
             call read_qinit(qinit_fname)
 
@@ -229,4 +225,4 @@ contains
         
     end subroutine read_qinit
 
-end module qinit_module
\ No newline at end of file
+end module qinit_module
