@@ -38,15 +38,15 @@ c      # in rp2, but shouldn't matter since wave is not used in qad
 c      # and for other arrays it is only the last parameter that is wrong
 c      #  ok as long as meqn, mwaves < maxvar
 
-       parameter (max1dp1 = max1d+1)
-       dimension ql(nvar,max1dp1),    qr(nvar,max1dp1)
-       dimension wave(nvar,mwaves,max1dp1), s(mwaves,max1dp1)
-       dimension amdq(nvar,max1dp1),  apdq(nvar,max1dp1)
-       dimension auxl(maxaux*max1dp1),  auxr(maxaux*max1dp1)
+       integer max1dp1
+       dimension ql(nvar,max1d+1),    qr(nvar,max1d+1)
+       dimension wave(nvar,mwaves,max1d+1), s(mwaves,max1d+1)
+       dimension amdq(nvar,max1d+1),  apdq(nvar,max1d+1)
+       dimension auxl(maxaux*(max1d+1)),  auxr(maxaux*(max1d+1))
 c
 c  WARNING: auxl,auxr dimensioned at max possible, but used as if
-c  they were dimensioned as the real maux by max1dp1. Would be better
-c  of course to dimension by maux by max1dp1 but this wont work if maux=0
+c  they were dimensioned as the real maux by max1d+1. Would be better
+c  of course to dimension by maux by max1d+1 but this wont work if maux=0
 c  So need to access using your own indexing into auxl,auxr.
        iaddaux(iaux,i) = iaux + maux*(i-1)
 
@@ -69,6 +69,7 @@ c       return
 
 c  ---------------------------------------------------------------
 
+       max1dp1 = max1d + 1
 
        if (qprint) write(dbugunit,*)" working on grid ",mptr
        tgrid = rnode(timemult, mptr)
