@@ -13,8 +13,6 @@ module refinement_module
     ! ========================================================================
     real(kind=8) :: wave_tolerance
     real(kind=8), allocatable :: speed_tolerance(:)
-    real(kind=8) :: deep_depth
-    integer :: max_level_deep
     logical :: varRefTime = .FALSE. ! Choose dt refinement automatically
     
     ! ========================================================================
@@ -63,8 +61,6 @@ contains
             read(unit,'(a)') line
             allocate(speed_tolerance(get_value_count(line)))
             read(line,*) speed_tolerance
-            read(unit,*) deep_depth
-            read(unit,*) max_level_deep
             read(unit,*)
             read(unit,*) varRefTime
             close(unit)
@@ -72,8 +68,6 @@ contains
             ! Write out data to parameter file
             write(GEO_PARM_UNIT,*) '   wave_tolerance:',wave_tolerance
             write(GEO_PARM_UNIT,*) '   speed_tolerance:',speed_tolerance
-            write(GEO_PARM_UNIT,*) '   maxleveldeep:', max_level_deep
-            write(GEO_PARM_UNIT,*) '   depthdeep:', deep_depth
             write(GEO_PARM_UNIT,*) '   Variable dt Refinement Ratios:',varRefTime
             write(GEO_PARM_UNIT,*) ''
             
