@@ -22,7 +22,7 @@ module topo_module
     integer, allocatable ::  mxtopo(:), mytopo(:)
 
     integer, allocatable :: i0topo(:), mtopo(:), mtopoorder(:)
-    integer, allocatable :: minleveltopo(:), maxleveltopo(:), itopotype(:)
+    integer, allocatable :: itopotype(:)
     integer, allocatable :: topoID(:),topo0save(:)
     logical :: topo_finalized
 
@@ -43,14 +43,14 @@ module topo_module
     real(kind=8) :: dt_max_dtopo
 
     ! File data parameters
-    character*150, allocatable :: dtopofname(:)
+    character (len=150), allocatable :: dtopofname(:)
     real(kind=8), allocatable :: xlowdtopo(:),ylowdtopo(:),xhidtopo(:)
     real(kind=8), allocatable :: yhidtopo(:),t0dtopo(:),tfdtopo(:)
     real(kind=8), allocatable :: dxdtopo(:),dydtopo(:),dtdtopo(:)
     real(kind=8), allocatable :: tdtopo1(:),tdtopo2(:),taudtopo(:)
 
     integer, allocatable :: mxdtopo(:),mydtopo(:),mtdtopo(:),mdtopo(:)
-    integer, allocatable :: minleveldtopo(:),maxleveldtopo(:),dtopotype(:)
+    integer, allocatable :: dtopotype(:)
     integer, allocatable :: i0dtopo(:),mdtopoorder(:),kdtopo1(:),kdtopo2(:)
     integer, allocatable :: index0_dtopowork1(:),index0_dtopowork2(:)
 
@@ -83,7 +83,7 @@ contains
     ! Finest value of topography in a given region will be used for
     ! computation
     ! ========================================================================
-    subroutine read_topo_settings(file_name)
+    subroutine read_topo_settings(restart,file_name)
 
         use geoclaw_module
 
@@ -91,13 +91,13 @@ contains
 
         ! Input arguments
         character(len=*), intent(in), optional :: file_name
+        logical, intent(in) :: restart
 
         ! Locals
         integer, parameter :: iunit = 7
-        integer :: i,j,itopo,finer_than,rank
-        real(kind=8) :: area_i,area_j,x_junk,y_junk
+        integer :: i,j,finer_than,rank
+        real(kind=8) :: area_i,area_j
         real(kind=8) :: area, area_domain
-
         if (.not.module_setup) then
 
             ! Open and begin parameter file output
@@ -112,7 +112,6 @@ contains
             else
                 call opendatafile(iunit, 'topo.data')
             endif
-
             ! Read in value to use in place of no_data_value in topofile
             read(iunit,*) topo_missing
 
@@ -132,29 +131,24 @@ contains
 
                 mtopofiles = mtopofiles + num_dtopo
                 write(GEO_PARM_UNIT,*) '   mtopofiles = ',mtopofiles-num_dtopo
-
+                
                 ! Read and allocate data parameters for each file
                 allocate(mxtopo(mtopofiles),mytopo(mtopofiles))
                 allocate(xlowtopo(mtopofiles),ylowtopo(mtopofiles))
                 allocate(tlowtopo(mtopofiles),xhitopo(mtopofiles),yhitopo(mtopofiles))
                 allocate(thitopo(mtopofiles),dxtopo(mtopofiles),dytopo(mtopofiles))
                 allocate(topofname(mtopofiles),itopotype(mtopofiles))
-                allocate(minleveltopo(mtopofiles),maxleveltopo(mtopofiles))
                 allocate(i0topo(mtopofiles),mtopo(mtopofiles),mtopoorder(mtopofiles))
                 allocate(topoID(mtopofiles),topotime(mtopofiles),topo0save(mtopofiles))
                 allocate(i0topo0(mtopofiles),topo0ID(mtopofiles))
 
                 do i=1,mtopofiles - num_dtopo
                     read(iunit,*) topofname(i)
-                    read(iunit,*) itopotype(i),minleveltopo(i), maxleveltopo(i), &
-                        tlowtopo(i),thitopo(i)
+                    read(iunit,*) itopotype(i)
 
                     write(GEO_PARM_UNIT,*) '   '
                     write(GEO_PARM_UNIT,*) '   ',topofname(i)
                     write(GEO_PARM_UNIT,*) '  itopotype = ', itopotype(i)
-                    write(GEO_PARM_UNIT,*) '  minlevel, maxlevel = ', &
-                        minleveltopo(i), maxleveltopo(i)
-                    write(GEO_PARM_UNIT,*) '  tlow, thi = ', tlowtopo(i),thitopo(i)
                     if (abs(itopotype(i)) == 1) then
                         print *, 'WARNING: topotype 1 has been deprecated'
                         print *, 'converting to topotype > 1 is encouraged'
@@ -182,10 +176,6 @@ contains
                    yhitopo(i) = yhidtopo(j)
                    dxtopo(i) = dxdtopo(j)
                    dytopo(i) = dydtopo(j)
-                   minleveltopo(i) = minleveldtopo(j)
-                   maxleveltopo(i) = maxleveldtopo(j)
-                   tlowtopo(i) = t0dtopo(j)
-                   thitopo(i) = tfdtopo(j)
                    mtopo(i) = mxtopo(i)*mytopo(i)
                    topoID(i) = i
                    topotime(i) = -huge(1.0)
@@ -260,8 +250,7 @@ contains
                 !this call will also determine which topo arrays to save in topo0work
                 do i = mtopofiles - num_dtopo + 1, mtopofiles
                    call set_topo_for_dtopo(mxtopo(i),mytopo(i),dxtopo(i),dytopo(i), &
-                        xlowtopo(i),ylowtopo(i),xhitopo(i),yhitopo(i), &
-                        topowork(i0topo(i):i0topo(i)+mtopo(i)-1))
+                        xlowtopo(i),yhitopo(i), topowork(i0topo(i):i0topo(i)+mtopo(i)-1))
                 enddo
 
                 !create topo0work array for finest arrays covering dtopo
@@ -270,7 +259,10 @@ contains
                 aux_finalized = 2   !# indicates aux arrays properly set with dtopo
                 if (num_dtopo>0) then
                    topo_finalized = .false.
-                   aux_finalized = 0  !# will be incremented each time level 1 goes
+                   if (.not. restart) then ! rest is read in
+                      aux_finalized = 0  !# will be incremented each time level 1 goes
+                   endif
+
                    i0topo0(1) = 1
                    mtopo0size = dot_product(mtopo,topo0save)
                    allocate(topo0work(mtopo0size))
@@ -338,15 +330,15 @@ contains
     !  array values come from the finest topography already in topowork
     ! ========================================================================
 
-    subroutine set_topo_for_dtopo(mx,my,dx,dy,xlow,ylow,xhi,yhi,newtopo)
+    subroutine set_topo_for_dtopo(mx,my,dx,dy,xlow,yhi,newtopo)
 
         !arguments
         integer, intent(in) :: mx,my
-        real(kind=8), intent(in) :: dx,dy,xlow,xhi,ylow,yhi
+        real(kind=8), intent(in) :: dx,dy,xlow,yhi
         real(kind=8), intent(inout) :: newtopo(1:mx*my)
 
         !locals
-        integer :: i,j,k,ij,id,irank,itopo1,itopo2,jtopo1,jtopo2
+        integer :: i,j,ij,id,irank,itopo1,itopo2,jtopo1,jtopo2
         integer :: ijll,ijlr,ijul,ijur
         real(kind=8) :: x,y,xl,xr,yu,yl,zll,zlr,zul,zur,z,dxdy
 
@@ -438,21 +430,20 @@ contains
         ! Locals
         integer, parameter :: iunit = 19, miss_unit = 17
         logical, parameter :: maketype2 = .false.
-        integer :: i,j,num_points,missing,status,topo_start,n
-        real(kind=8) :: no_data_value,x,y,z,topo_temp
+        integer :: i,j,missing,status,n
+        real(kind=8) :: no_data_value,x,y,topo_temp
         real(kind=8) :: values(10)
         character(len=80) :: str
-        integer(kind=4) :: row_index
 
         ! NetCDF Support
         character(len=10) :: direction, x_dim_name, x_var_name, y_dim_name, &
-            y_var_name, z_var_name, var_name, dim_name_tmp
+            y_var_name, z_var_name, var_name
         ! character(len=1) :: axis_string
         real(kind=8), allocatable :: nc_buffer(:, :), xlocs(:), ylocs(:)
         integer(kind=4) :: x_var_id, y_var_id, z_var_id, x_dim_id, y_dim_id
-        integer(kind=4) :: xstart(1), ystart(1), mx_tot, my_tot, m_tmp
-        integer(kind=4) :: ios, nc_file, num_values, dim_ids(2), num_dims, &
-            var_type, var_ids(2), num_vars, num_dims_tot, z_dim_ids(2)
+        integer(kind=4) :: xstart(1), ystart(1), mx_tot, my_tot
+        integer(kind=4) :: ios, nc_file, dim_ids(2), num_dims, &
+            var_type, num_vars, num_dims_tot, z_dim_ids(2)
 
         print *, ' '
         print *, 'Reading topography file  ', fname
@@ -731,7 +722,7 @@ contains
 
         ! Local
         integer, parameter :: iunit = 19
-        integer :: topo_size, status, n, i
+        integer :: topo_size, status, n
         real(kind=8) :: x,y,z,nodata_value
         logical :: found_file
         real(kind=8) :: values(10)
@@ -743,10 +734,11 @@ contains
         ! character(len=1) :: axis_string
         ! character(len=6) :: convention_string
         ! integer(kind=4) :: convention_version
-        integer(kind=4) :: ios, nc_file, num_values
+        integer(kind=4) :: nc_file
         real(kind=8), allocatable :: xlocs(:),ylocs(:)
         logical, allocatable :: x_in_dom(:),y_in_dom(:)
-        integer(kind=4) :: dim_ids(2), num_dims, var_type, var_ids(2), num_vars, num_dims_tot
+        integer(kind=4) :: dim_ids(2), num_dims, var_type, num_vars, num_dims_tot
+        integer(kind=4), allocatable :: var_ids(:)
         character(len=10) :: var_name, x_var_name, y_var_name, z_var_name
         character(len=10) :: x_dim_name, y_dim_name
         integer(kind=4) :: x_var_id, y_var_id, z_var_id, x_dim_id, y_dim_id
@@ -895,8 +887,8 @@ contains
                 call get_dim_info(nc_file, num_dims_tot, x_dim_id, x_dim_name, &
                     mx, y_dim_id, y_dim_name, my)
                 
-                ! allocate vector to hold lon and lat vals
-                allocate(xlocs(mx),ylocs(my),x_in_dom(mx),y_in_dom(my))
+                ! allocate vector to hold lon and lat vals and vector for var ids
+                allocate(xlocs(mx),ylocs(my),x_in_dom(mx),y_in_dom(my),var_ids(num_vars))
 
                 if (verbose) then
                     print *, "Names = (", x_dim_name, ", ", y_dim_name, ")"
@@ -988,12 +980,12 @@ contains
 
     end subroutine read_topo_header
 
-    real(kind=8) pure function test_topo(x,y) result(topography)
+    real(kind=8) pure function test_topo(x) result(topography)
 
         implicit none
 
         ! Arguments
-        real(kind=8), intent(in) :: x,y
+        real(kind=8), intent(in) :: x
 
         if (test_topography == 1) then
             if (x < topo_location) then
@@ -1043,18 +1035,13 @@ contains
         implicit none
 
         ! Input arguments
-        character*25, optional, intent(in) :: file_name
+        character (len=25), optional, intent(in) :: file_name
 
         ! Locals
         integer, parameter :: iunit = 79
         integer :: itopo,finer_than,rank
         real(kind=8) :: area_i,area_j
-        real(kind=8) :: xcell, xim, xip, ycell, yjm, yjp, ztopoij
-        real(kind=8) :: capac_area
-        integer :: i,j,m,ib,jb,ij,ijdtopo,jbr
-
-        ! Function
-        real(kind=8) :: topointegral
+        integer :: i,j
 
         write(GEO_PARM_UNIT,*) ' '
         write(GEO_PARM_UNIT,*) '--------------------------------------------'
@@ -1074,8 +1061,8 @@ contains
         endif
 
         ! Allocate and read in dtopo info
-        allocate(dtopofname(num_dtopo),minleveldtopo(num_dtopo))
-        allocate(maxleveldtopo(num_dtopo),mxdtopo(num_dtopo))
+        allocate(dtopofname(num_dtopo))
+        allocate(mxdtopo(num_dtopo))
         allocate(mydtopo(num_dtopo),mtdtopo(num_dtopo),mdtopo(num_dtopo))
         allocate(xlowdtopo(num_dtopo),ylowdtopo(num_dtopo),t0dtopo(num_dtopo))
         allocate(xhidtopo(num_dtopo),yhidtopo(num_dtopo),tfdtopo(num_dtopo))
@@ -1088,11 +1075,9 @@ contains
 
         do i=1,num_dtopo
             read(iunit,*) dtopofname(i)
-            read(iunit,*) dtopotype(i),minleveldtopo(i), maxleveldtopo(i)
+            read(iunit,*) dtopotype(i)
             write(GEO_PARM_UNIT,*) '   fname:',dtopofname(i)
             write(GEO_PARM_UNIT,*) '   topo type:',dtopotype(i)
-            write(GEO_PARM_UNIT,*) '   minlevel, maxlevel:'
-            write(GEO_PARM_UNIT,*)  minleveldtopo(i),maxleveldtopo(i)
 
             ! Read in header data
             call read_dtopo_header(dtopofname(i),dtopotype(i),mxdtopo(i), &
@@ -1157,12 +1142,12 @@ contains
 
       ! Arguments
       integer, intent(in) :: mx,my,mt,dtopo_type
-      character*150, intent(in) :: fname
+      character (len=150), intent(in) :: fname
       real(kind=8), intent(inout) :: dtopo(1:mx*my*mt)
 
       ! Local
       integer, parameter :: iunit = 29
-      integer :: i,j,k,dtopo_size,status
+      integer :: i,j,k,status
       real(kind=8) :: t,x,y
 
       open(unit=iunit, file=fname, status = 'unknown',form='formatted')
@@ -1221,7 +1206,7 @@ contains
         implicit none
 
         ! Input Arguments
-        character*150, intent(in) :: fname
+        character (len=150), intent(in) :: fname
         integer, intent(in) :: topo_type
 
         ! Output Arguments
@@ -1231,7 +1216,7 @@ contains
         ! Locals
         integer, parameter :: iunit = 7
         integer :: topo_size,status
-        real(kind=8) :: x,y,t,y_old,t_old
+        real(kind=8) :: x,y,t,y_old
         logical :: found_file
 
         ! Open file
@@ -1431,7 +1416,7 @@ recursive subroutine rectintegral(x1,x2,y1,y2,m,integral)
     ! local
     real(kind=8) :: xmlo,xmhi,ymlo,ymhi,area,x1m,x2m, &
         y1m,y2m, int1,int2,int3
-    integer :: mfid, indicator, mp1fid, i0
+    integer :: mfid, indicator, i0
     real(kind=8), external :: topointegral  
 
 
@@ -1574,4 +1559,4 @@ function Upper(s1)  RESULT (s2)
     END DO
 END function Upper
 
-end module topo_module
\ No newline at end of file
+end module topo_module
