@@ -8,7 +8,7 @@ One-dimensional advection
 Solve the linear advection equation:
 
 .. math:: 
-    q_t + u q_x & = 0.
+    q_t + u q_x = 0.
 
 Here q is the density of some conserved quantity and u is the velocity.
 
@@ -16,6 +16,7 @@ The initial condition is a Gaussian and the boundary conditions are periodic.
 The final solution is identical to the initial data because the wave has
 crossed the domain exactly once.
 """
+from __future__ import absolute_import
 import numpy as np
 from clawpack import riemann
 
@@ -38,6 +39,9 @@ def setup(nx=100, kernel_language='Python', use_petsc=False, solver_type='classi
         solver = pyclaw.SharpClawSolver1D(riemann_solver)
         solver.weno_order = weno_order
         solver.time_integrator = time_integrator
+        if time_integrator == 'SSPLMMk3':
+            solver.lmm_steps = 5
+            solver.check_lmm_cond = True
     else: raise Exception('Unrecognized value of solver_type.')
 
     solver.kernel_language = kernel_language
@@ -45,7 +49,7 @@ def setup(nx=100, kernel_language='Python', use_petsc=False, solver_type='classi
     solver.bc_lower[0] = pyclaw.BC.periodic
     solver.bc_upper[0] = pyclaw.BC.periodic
 
-    x = pyclaw.Dimension('x',0.0,1.0,nx)
+    x = pyclaw.Dimension(0.0,1.0,nx,name='x')
     domain = pyclaw.Domain(x)
     state = pyclaw.State(domain,solver.num_eqn)
 
