@@ -15,21 +15,29 @@ Here h is the depth, u is the velocity, and g is the gravitational constant.
 The default initial condition used here models a dam break.
 """
 
+from __future__ import absolute_import
 import numpy as np
 from clawpack import riemann
 from clawpack.riemann.shallow_roe_with_efix_1D_constants import depth, momentum, num_eqn
 
-def setup(use_petsc=False,kernel_language='Fortran',outdir='./_output',solver_type='classic'):
+def setup(use_petsc=False,kernel_language='Fortran',outdir='./_output',solver_type='classic',
+          riemann_solver='roe', disable_output=False):
 
     if use_petsc:
         import clawpack.petclaw as pyclaw
     else:
         from clawpack import pyclaw
 
-    if kernel_language =='Python':
-        rs = riemann.shallow_1D_py.shallow_1D
-    elif kernel_language =='Fortran':
-        rs = riemann.shallow_roe_with_efix_1D
+    if kernel_language == 'Python':
+        if riemann_solver.lower() == 'roe':
+            raise Exception('Python Roe solver not implemented.')
+        elif riemann_solver.lower() == 'hlle':
+            rs = riemann.shallow_1D_py.shallow_hll_1D
+    elif kernel_language == 'Fortran':
+        if riemann_solver.lower() == 'roe':
+            rs = riemann.shallow_roe_with_efix_1D
+        elif riemann_solver.lower() == 'hlle':
+            rs = riemann.shallow_hlle_1D
  
     if solver_type == 'classic':
         solver = pyclaw.ClawSolver1D(rs)
@@ -37,7 +45,7 @@ def setup(use_petsc=False,kernel_language='Fortran',outdir='./_output',solver_ty
     elif solver_type == 'sharpclaw':
         solver = pyclaw.SharpClawSolver1D(rs)
 
-    solver.kernel_language=kernel_language
+    solver.kernel_language = kernel_language
 
     solver.bc_lower[0] = pyclaw.BC.extrap
     solver.bc_upper[0] = pyclaw.BC.extrap
@@ -45,12 +53,14 @@ def setup(use_petsc=False,kernel_language='Fortran',outdir='./_output',solver_ty
     xlower = -5.0
     xupper = 5.0
     mx = 500
-    x = pyclaw.Dimension('x',xlower,xupper,mx)
+    x = pyclaw.Dimension(xlower,xupper,mx,name='x')
     domain = pyclaw.Domain(x)
     state = pyclaw.State(domain,num_eqn)
 
     # Gravitational constant
     state.problem_data['grav'] = 1.0
+    state.problem_data['dry_tolerance'] = 1e-3
+    state.problem_data['sea_level'] = 0.0
     
     xc = state.grid.x.centers
 
@@ -78,6 +88,8 @@ def setup(use_petsc=False,kernel_language='Fortran',outdir='./_output',solver_ty
 
     claw = pyclaw.Controller()
     claw.keep_copy = True
+    if disable_output:
+        claw.output_format = None
     claw.tfinal = 2.0
     claw.solution = pyclaw.Solution(state,domain)
     claw.solver = solver
