@@ -21,4 +21,9 @@ class PetClawIOTest(pyclaw.IOTest):
         return os.path.join(self.this_dir, '../../pyclaw/tests/test_data')
 
     def test_io_from_binary(self):
-        return
\ No newline at end of file
+        return
+
+    def test_io_to_vtk(self):
+        return # this test is not valid for petclaw b/c can't read binary.
+        # note that petclaw can write VTK through the PETSC vtk writing
+        # capabilities. 
