@@ -40,8 +40,8 @@ subroutine rp1(maxm,meqn,mwaves,maux,mbc,mx,ql,qr,auxl,auxr,wave,s,amdq,apdq)
 
     implicit double precision (a-h,o-z)
 
-    dimension auxl(2, 1-mbc:maxm+mbc)
-    dimension auxr(2, 1-mbc:maxm+mbc)
+    dimension auxl(maux, 1-mbc:maxm+mbc)
+    dimension auxr(maux, 1-mbc:maxm+mbc)
     dimension wave(meqn, mwaves, 1-mbc:maxm+mbc)
     dimension    s(mwaves, 1-mbc:maxm+mbc)
     dimension   ql(meqn, 1-mbc:maxm+mbc)
